@@ -17,12 +17,10 @@
  * by the loader of the operating system.
  */
 
-#include "imp.h"
 #include <assert.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <signal.h>
 #include <string.h>
 #include <unistd.h>
 #include <time.h>
@@ -36,23 +34,16 @@
 #include <mcheck.h>
 #endif
 
-#include "defines.h"
 #include "conn.h"
 #include "class.h"
-#include "conf-ssl.h"
 #include "channel.h"
 #include "conf.h"
-#include "lists.h"
 #include "log.h"
-#include "parse.h"
 #include "sighandlers.h"
 #include "io.h"
-#include "irc.h"
 
-#include "exp.h"
 #include "ngircd.h"
 
-
 static void Show_Version PARAMS(( void ));
 static void Show_Help PARAMS(( void ));
 
